pub enum Error {
Show 20 variants
NoOpenVault,
NotDirectory(PathBuf),
NotFileContent,
NoCache,
NoFolderPassword(VaultId),
NoFilePassword,
SecretNotFound(SecretId),
NoVaultEvent,
TryFromSlice(TryFromSliceError),
FileSystem(Error),
Vault(Error),
Login(Error),
Core(Error),
Authentication(AuthenticationError),
Password(Error),
Sync(Error),
BackendStorage(StorageError),
Backend(Error),
Database(Error),
Io(Error),
}Expand description
Errors generated by the client storage library.
Variants
NoOpenVault
Error generated attempting to make changes to the current vault but no vault is open.
NotDirectory(PathBuf)
Error generated when a directory is expected.
NotFileContent
Error generated when a file secret is expected.
NoCache
Error generated if we could not determine a cache directory.
NoFolderPassword(VaultId)
Error generated when a folder password in the identity vault could not be located.
NoFilePassword
Error generated when a file encryption password is required.
SecretNotFound(SecretId)
Error generated when a secret could not be found.
NoVaultEvent
Error generated if we could not find a create vault event in a collection of event records or as the first event in a folder event log.
TryFromSlice(TryFromSliceError)
Error generated converting to fixed length slice.
FileSystem(Error)
Error generated by the filesystem library.
Vault(Error)
Error generated by the vault library.
Login(Error)
Error generated by the login library.
Core(Error)
Errors generated by the core library.
Authentication(AuthenticationError)
Authentication errors.
Password(Error)
Errors generated by the password library.
Sync(Error)
Errors generated by the sync library.
BackendStorage(StorageError)
Errors generated by the backend storage.
Backend(Error)
Errors generated by the backend library.
Database(Error)
Errors generated by the database library.
Io(Error)
Errors generated by the IO module.