pub enum ClientStorage {
FileSystem(SyncImpl<ClientFileSystemStorage>),
Database(SyncImpl<ClientDatabaseStorage>),
}Expand description
Client account storage.
Variants
FileSystem(SyncImpl<ClientFileSystemStorage>)
Filesystem storage.
Database(SyncImpl<ClientDatabaseStorage>)
Database storage.
Implementations
Sourceimpl ClientStorage
impl ClientStorage
Sourcepub async fn new_unauthenticated(
target: BackendTarget,
account_id: &AccountId,
) -> Result<Self, Error>
pub async fn new_unauthenticated( target: BackendTarget, account_id: &AccountId, ) -> Result<Self, Error>
Create new client storage.
Sourcepub async fn new_account(
target: BackendTarget,
account_id: &AccountId,
account_name: String,
) -> Result<Self, Error>
pub async fn new_account( target: BackendTarget, account_id: &AccountId, account_name: String, ) -> Result<Self, Error>
Create a new account in client storage.
The account must not already exist.
Only to be used when fetching account data from a remote during device enrollment.
Sourcepub async fn rebuild_folder_vault(
target: BackendTarget,
account_id: &AccountId,
folder_id: &VaultId,
) -> Result<Vec<u8>, Error>
pub async fn rebuild_folder_vault( target: BackendTarget, account_id: &AccountId, folder_id: &VaultId, ) -> Result<Vec<u8>, Error>
Rebuild the vault for a folder from event logs.
Can be used to repair a vault from a collection of event logs or to convert server-side head-only vaults into the client-side representation.
Authentication
Can be called when the account is not authenticated.